% clean_up_data() - back-projection with artifactual component removed according 
%                   to the field of FMRI.rejcomp, and export the cleaned data
%                   in ANALYZE data format for the further analysis using other 
%                   software (with graphic user interface
%
% Usage:
%   >> clean_up_data;
%
% Inputs:
%
% Outputs:
%
% Author: Jeng-Ren Duann, CNL/Salk Inst., 2004-03
% See also: map_on_fmri(), map_on_struc()

function clean_up_data

global FMRI

% check if FMRI data structure is empty
if length(FMRI) == 0,
    fmrlab_messagedlg('clean_up_data()',...
        'Error:',...
        'No FMR dataset available');
    return;
end

% check if FMRI.rej_comp is empty
if isempty(FMRI.rejcomp),
    fmrlab_messagedlg('clean_up_data()',...
        'Error:',...
        'No rejected components specified');
    return;
end

% check if ICA decomposition is done
if length(FMRI.icaweight) == 0,
    fmrlab_messagedlg('clean_up_data()',...
        'Error',...
        'No ICA weights found, please run ICA first');
    return;
end

% perform back-projection without artifactual components
W = FMRI.icaweight * FMRI.icasphere;
invW = pinv(W);
u = W * FMRI.data;
FMRI.rejcomp = FMRI.rejcomp(:);
for i=1:length(FMRI.rejcomp),
    u(FMRI.rejcomp(i),:) = zeros(1,size(u,2));
end
temp = invW * u;
temp = temp-min(min(temp));

% recover the images according to the field FMRI.idx
new_data = zeros(FMRI.timepoint,FMRI.dime_x*FMRI.dime_y*FMRI.dime_z);
for i=1:length(FMRI.idx),
    new_data(:,FMRI.idx(i)) = temp(:,i);
end

% popup window for user to specify filename for exporting clean dataset
[filename, pathname] = uiputfile('*.img', 'Pick an Analyze-file');
i = findstr(filename,'.');
hdr_file = [pathname filename(1:i-1) '.hdr'];
img_file = [pathname filename];

% call spm_hwrite to write header file
spm_hwrite(hdr_file,...
    [FMRI.dime_x FMRI.dime_y FMRI.dime_z FMRI.timepoint],...
    [FMRI.fov_x/FMRI.dime_x FMRI.fov_y/FMRI.dime_y FMRI.slicetk, FMRI.tr],...
    1,...
    4,...
    0,...
    [0 0 0],...
    'ICA-cleaned');

% write image body
new_data = new_data';
fp = fopen(img_file,'wb','ieee-be');
fwrite(fp,new_data,'int16');
fclose(fp);