% fmrlab_eventgen() - generate event table for FMRI data structure
%                     to tie closely the event the BOLD signal and
%                     make the display of event-related BOLD image
%
% Usage: 
%   >> fmrlab_eventgen;
%
% Input:
%
% Output:
%
% Author: Jeng-Ren Duann, SCCN/INC/UCSD & CNL/Salk Inst. 2003-09-25
%
% See also:
%   fmrlab_eventedit(), set_fmri_global_ui()
%
% Note:
%   1. This function reads event log files from Presentations
%   2. This function will create a new event table and add it to
%      FMRI data structure
%   3. If the event table exists, this this function will create
%      another one according to the input and overwrite the
%      existing one.
%   4. To avoid overwriting the existing event table, please use
%      fmrlab_eventedit().
%   

% --
% Copyright (C) 2003 Jeng-Ren Duann, SCCN/INC/UCSD, duann@salk.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% $Log: fmrlab_eventgen.m,v $

function fmrlab_eventgen()
  
global FMRI

if length(FMRI) == 0,
  fmrlab_messagedlg('fmrlab_eventgen()',...
		    'Error:',...
		    ['No available FMRI data, please load FMRI data' ...
		     ' first']);
  return;
end

fmrlab_chkdataset;

if ~isempty(FMRI.event),
  but_pressed = fmrlab_messagedlg('fmrlab_eventgen()',...
		    'Warning:',...
		    ['This function will overwrite the existing event' ...
		     [' table, do you still want to create a new' ...
		      ' event table?']],...
		    {'Yes','No'});
  if but_pressed == 2,
    return;
  end
end

% reset event field to create new event table
FMRI.event = [];

str_blank = sprintf(' ');
str_tab = sprintf('\t');

% popup window to select event log file
[filename,pathname] = uigetfile('*','Select Event Log File');
fname = [pathname filename];
fp = fopen(fname,'r');
if fp == -1,
  fmrlab_messagedlg('fmrlab_eventgen()',...
		    'Error:',...
		    'Cannot open event log file');
  return;
end

disp('Import events from Presentation LOG file...');

a = fgets(fp);
FMRI.eventhdr.scenario = a;
a = fgets(fp);
a = fgets(fp);
b = findstr(a,' ');
FMRI.eventhdr.date = a(b(3)+1:b(4)-1);
FMRI.eventhdr.time = a(b(4)+1:b(5)-1);
a = fgets(fp);
a = fgets(fp);
a = fgets(fp);
a = fgets(fp);
ii_tab = findstr(a,str_tab);
allfields = [];
ii_tab = [1 ii_tab length(a)];
for i=1:length(ii_tab)-1,
  allfields{i} = a(ii_tab(i):ii_tab(i+1));
end
allfields=deblank(allfields);
for i=1:length(allfields),
  ii = findstr(allfields{i},str_tab);
  allfields{i}(ii) = [];
  ii = findstr(allfields{i},str_blank);
  allfields{i}(ii) = [];
end

ind = 1;
while ~feof(fp),
  a = fgets(fp);
  % check if the read-in string is empty
  ii = isspace(a);
  ii2 = find(ii==0);
  if ~isempty(ii2),
    ii_tab = findstr(a,str_tab);
    ii_tab = [1 ii_tab length(a)];
    allvals = [];
    for i=1:length(ii_tab)-1,
      allvals{i} = a(ii_tab(i):ii_tab(i+1));
    end
    allvals = deblank(allvals);
    for i=1:length(allvals),
      ii = findstr(allvals{i},str_tab);
      if ~isempty(ii),
	allvals{i}(ii) = [];
      end
    end
    % fill in event vals
    % save all field vals as 'string'
    if length(allvals)>2,
      if strcmp(allvals{2},'Response')==1,
	FMRI.event{ind} = struct(...
	    allfields{1},allvals{1},...
	    allfields{2},allvals{2},...
	    allfields{3},allvals{3},...
	    allfields{4},allvals{4},...
	    allfields{5},allvals{5},...
	    [allfields{6} '1'],allvals{6},...
	    allfields{7},'',...
	    [allfields{8} '2'],'',...
	    allfields{9},'',...
	    allfields{10},'');
      else
	FMRI.event{ind} = struct(...
	    allfields{1},allvals{1},...
	    allfields{2},allvals{2},...
	    allfields{3},allvals{3},...
	    allfields{4},allvals{4},...
	    allfields{5},allvals{5},...
	    [allfields{6} '1'],allvals{6},...
	    allfields{7},allvals{7},...
	    [allfields{8} '2'],allvals{8},...
	    allfields{9},allvals{9},...
	    allfields{10},allvals{10});
      end
      ind = ind+1;
    end
  end
end

fclose(fp);

disp('Done.');
