% resort_comp() - Resort independent components according to the
%                 condition specified by users
% Usage:
%   >> execute_ica;
%
% Inputs:
%
% Outputs:
%
% Author: Jeng-Ren Duann, CNL/Salk Inst. & SCCN/INC/UCSD, 2004-08
%
% See also: execute_ica()

% --
% Copyright (C) 2004 Jeng-Ren Duann, SCCN/INC/UCSD, duann@sccn.ucsd.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software

% $Log: resort_comp.m,v $
% Revision 1.1  2004/08/05 17:43:44  duann
% Initial revision
%

function resort_comp
  
  global FMRI
  
  % asking users if they want to resort components in different order
  prompt = sprintf('\n\n0 - Default (Comp. Power)\n');
  prompt = [prompt sprintf('1 - Comp. Kurtosis\n')];
  prompt = [prompt sprintf('2 - Comp. Skewness\n')];
  prompt = [prompt sprintf('3 - Comp. Variance\n')];
  prompt = [prompt sprintf('4 - ROA Complexity\n')];
  a = fmrlab_inputdlg(prompt,'Resort components',1,{'0'});
  if isempty(a),
    return;
  else
    ii = str2num(char(a(1)));
  end

  set(gcf,'pointer','watch');
  
  w = FMRI.icaweight;
  sph = FMRI.icasphere;
  W = w * sph;
  u = W * FMRI.data;
  switch(ii)
   case 0,
    invW = pinv(W);
    for i=1:size(FMRI.icaweight,1),
      data2 = invW(:,i)*u(i,:);
      kk(i) = mean(sum(data2.*data2)/(size(data2,1)-1));
    end
    [i,j] = sort(kk);
    j = fliplr(j);
    FMRI.icaweight = w(j,:);
    FMRI.icasphere = sph;
   case 1,
    kk = kurtosis(u');
    [i,j] = sort(kk);
    j = fliplr(j);
    FMRI.icaweight = w(j,:);
    FMRI.icasphere = sph;
   case 2,
    kk = skewness(u');
    [i,j] = sort(kk);
    j = fliplr(j);
    FMRI.icaweight = w(j,:);
    FMRI.icasphere = sph;
   case 3,
    invW = pinv(W);
    for i=1:size(FMRI.icaweight,1),
      data2 = invW(:,i)*u(i,:);
      kk(i) = 1-var(FMRI.data(:)-data2(:))/var(FMRI.data(:));
    end
    [i,j] = sort(kk);
    j = fliplr(j);
    FMRI.icaweight = w(j,:);
    FMRI.icasphere = sph;
    
   case 4,
    kk = roa_complexity(1:size(FMRI.icaweight,1));
    [i,j] = sort(kk);
    FMRI.icaweight = w(j,:);
    FMRI.icasphere = sph;
    
   otherwise,
    FMRI.icaweight = w;
    FMRI.icasphere = sph;
  end

  FMRI.comp_order = ii;
  
  set(gcf,'pointer','arrow');